@@ -65,7 +65,7 @@ def enter_and_leave_function(func: Callable) -> Callable:
                         f" finish run function {func.__name__}(), stdout is: {result.stdout} "
                     )
                 else:
-                    log.error(
+                    log.warning(
                         f"[{func_def_file}: {func_def_line}]"
                         f" failed to run function {func.__name__}(), stderr is: {result.stderr} "
                     )
